import type { EntryTagCollection } from '../entryTag'

/**
 * This describes aditional information about a project.
 * to display when listing the project on the portfolio page.
 * At minimum, the title should be specified.
 */
export type ProjectListingInfo = {
  /**[Supports Markdown]
   * Caption displayed below the title of the project on the projects page
   */
  caption?: string
  /**[Supports Markdown]
   * Optional subtitle for the project
   */
  subtitle?: string
  /**[Supports Markdown]
   * Information to summarize a project
   */
  summary?: string
  /**
   * Tags that correspond to project filters on the portfolio page if defined
   */
  tags?: string[]
  /**[Supports Markdown]
   * The title of the project
   */
  title: string
  /**[CSS:background]
   * Background image, repeat, attachment, and position for the project
   */
  thumbnailBackground?: string
  /**[CSS:background-size]
   * Background image size
   */
  thumbnailBackgroundSize?: string
}

export type ProjectList = {
  projects: { [key: string]: {
    config: string
    content: string
  }}
  tags?: EntryTagCollection
  removeFromView?: boolean
}
